#!/usr/bin/env python3
"""
Entry point for the r2midi_client package when executed directly.
This file allows the package to be run with 'python -m r2midi_client'.
"""

from r2midi_client.main import main

if __name__ == "__main__":
    main()