"""
Main entry point for the server package when executed directly.
This file is required for Briefcase to run the server in dev mode.
"""

from server.main import main

if __name__ == "__main__":
    main()